@@ -92,7 +92,8 @@ class BeamDataflowMixin(metaclass=ABCMeta):
 
     def __get_dataflow_job_name(self) -> str:
         return DataflowHook.build_dataflow_job_name(
-            self.dataflow_config.job_name, self.dataflow_config.append_job_name
+            self.dataflow_config.job_name,  # type: ignore
+            self.dataflow_config.append_job_name,
         )
 
     def __get_dataflow_pipeline_options(
@@ -194,6 +195,9 @@ class BeamBasePipelineOperator(BaseOperator, BeamDataflowMixin, ABC):
         else:
             self.dataflow_config = self.dataflow_config or DataflowConfiguration()
 
+        if not self.dataflow_config.job_name:
+            self.dataflow_config.job_name = self.task_id
+
         if self.dataflow_config and self.runner.lower() != BeamRunnerType.DataflowRunner.lower():
             self.log.warning(
                 "dataflow_config is defined but runner is different than DataflowRunner (%s)", self.runner
@@ -464,6 +468,7 @@ class BeamRunPythonPipelineOperator(BeamBasePipelineOperator):
             self.dataflow_hook.cancel_job(
                 job_id=self.dataflow_job_id,
                 project_id=self.dataflow_config.project_id,
+                location=self.dataflow_config.location,
             )
 
 
@@ -569,6 +574,7 @@ class BeamRunJavaPipelineOperator(BeamBasePipelineOperator):
                     is_running = self.dataflow_hook.is_job_dataflow_running(
                         name=self.dataflow_config.job_name,
                         variables=self.pipeline_options,
+                        location=self.dataflow_config.location,
                     )
 
                 if not is_running:
@@ -652,6 +658,7 @@ class BeamRunJavaPipelineOperator(BeamBasePipelineOperator):
             self.dataflow_hook.cancel_job(
                 job_id=self.dataflow_job_id,
                 project_id=self.dataflow_config.project_id,
+                location=self.dataflow_config.location,
             )
 
 
@@ -803,6 +810,7 @@ class BeamRunGoPipelineOperator(BeamBasePipelineOperator):
             self.dataflow_hook.cancel_job(
                 job_id=self.dataflow_job_id,
                 project_id=self.dataflow_config.project_id,
+                location=self.dataflow_config.location,
             )
 
 
